@@ -1,8 +1,6 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING, Iterator, List, Optional
-from pybi.core.components.statements import WithableStatement, StatementType
 
-from pybi.utils.data_gen import Jsonable, get_global_id
 from .componentTag import ComponentTag
 from .component import Component
 
@@ -136,9 +134,15 @@ class ColBoxComponent(ContainerComponent):
 
 
 class TabsComponent(ContainerComponent):
-    def __init__(self, names: List[str], appHost: Optional[App] = None) -> None:
+    def __init__(
+        self, names: List[str], mode="narrowing", appHost: Optional[App] = None
+    ) -> None:
+        """
+        mode: 'fullWidth' | 'narrowing'
+        """
         super().__init__(ComponentTag.Tabs, appHost)
         self.names = names
+        self.mode = mode
 
         for _ in range(len(self.names)):
             self._add_children(BoxComponent(appHost))
